﻿using System;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Windows;
using System.Windows.Data;

namespace CarouselExp
{
    public partial class MainWindow : Window, INotifyPropertyChanged
    {
        public MainWindow()
        {
            InitializeComponent();

            CarouselView = true;

            var list = new[] { 
                "Seattle Boeing Field  Isis", 
                "Seattle Seattle Tacoma Intl",
                "Snohomish Co", 
                "Felts Fld",
                "Spokane International Ap  Chen",
                "The Dalles Municipal Arpt",
                "Appleton Outagamie",
                "Whidbey Island Nas" };

            LoadsSource = CollectionViewSource.GetDefaultView(list);

            DataContext = this;
        }

        public bool CarouselView
        {
            get { return carouselView; }
            set 
            {
                carouselView = value;

                RaisePropertyChangedEvent();
            }
        }

        public string SearchKey
        {
            get { return searchKey; }
            set 
            {
                searchKey = value;

                LoadsSource.Filter = String.IsNullOrEmpty(searchKey)
                    ? (Predicate<Object>)null
                    : i => ((String)i).ToLower().Contains(searchKey.ToLower());

                RaisePropertyChangedEvent();
            }
        }

        public ICollectionView LoadsSource
        {
            get { return loadsSource; }
            set 
            {
                loadsSource = value;

                RaisePropertyChangedEvent();
            }
        }

        #region ** INotifyPropertyChanged

        public virtual void RaisePropertyChangedEvent([CallerMemberName] string propertyName = "")
        {
            if (PropertyChanged == null) return;

            PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion

        ICollectionView loadsSource;
        bool carouselView;
        string searchKey;
    }
}
